leaftools.fuse_leaves_in_container_once_by_counts
=================================================

.. autofunction:: abjad.tools.leaftools.fuse_leaves_in_container_once_by_counts.fuse_leaves_in_container_once_by_counts
   :noindex:
